@@ -1,6 +1,6 @@
 #  This file is part of PyBuilder
 #
-#  Copyright 2011-2013 PyBuilder Team
+#  Copyright 2011-2014 PyBuilder Team
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,13 +13,19 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-import inspect
+"""
+    The PyBuilder execution module.
+    Deals with the execution of a PyBuilder process by
+    running tasks, actions and initializers in the correct
+    order regarding dependencies.
+"""
 
+import inspect
 import re
 import types
 
 from pybuilder.errors import (CircularTaskDependencyException,
-                              InternalException,
+                              DependenciesNotResolvedException,
                               InvalidNameException,
                               MissingTaskDependencyException,
                               MissingActionDependencyException,
@@ -123,11 +129,6 @@ class Initializer(Executable):
                 return True
 
 
-class DependenciesNotResolvedException(InternalException):
-    def __init__(self):
-        super(DependenciesNotResolvedException, self).__init__("Dependencies have not been resolved.")
-
-
 class TaskExecutionSummary(object):
     def __init__(self, task, number_of_actions, execution_time):
         self.task = task
