@@ -68,7 +68,7 @@ def start_project():
 
 class PythonProjectScaffolding(object):
 
-    descriptor_template = string.Template("""
+    DESCRIPTOR_TEMPLATE = string.Template("""\
 from pybuilder.core import $core_imports
 
 use_plugin("python.core")
@@ -77,10 +77,14 @@ use_plugin("python.unittest")
 name = "${project_name}"
 default_task = "publish"
 
-$initializer
 
+$initializer
 """)
 
+    INITIALIZER_HEAD = '''@init
+def set_properties(project):
+'''
+
     def __init__(self, project_name):
         self.project_name = project_name
         self.dir_source_main_python = DEFAULT_SOURCE_DIRECTORY
@@ -91,12 +95,9 @@ $initializer
     def render_build_descriptor(self):
         self.build_initializer()
         self.core_imports = ', '.join(self.core_imports)
-        return self.descriptor_template.substitute(self.__dict__)
+        return self.DESCRIPTOR_TEMPLATE.substitute(self.__dict__)
 
     def build_initializer(self):
-        if self.is_default_source_main_python and self.is_default_source_unittest_python:
-            return
-
         self.core_imports.append('init')
 
         properties_to_set = []
@@ -105,12 +106,20 @@ $initializer
         if not self.is_default_source_unittest_python:
             properties_to_set.append(('dir_source_unittest_python', self.dir_source_unittest_python))
 
-        self.initializer = '''@init
-def set_properties(project):
-'''
-        self.initializer += '\n'.join(
+        initializer_body = self.build_initializer_body(properties_to_set)
+
+        self.initializer = self.INITIALIZER_HEAD + initializer_body
+
+    def build_initializer_body(self, properties_to_set):
+        initializer_body = ''
+        initializer_body += '\n'.join(
             ['    project.set_property("{0}", "{1}")'.format(k, v) for k, v in properties_to_set])
 
+        if not initializer_body:
+            initializer_body += '    pass'
+
+        return initializer_body
+
     @property
     def is_default_source_main_python(self):
         return self.dir_source_main_python == DEFAULT_SOURCE_DIRECTORY
